@@ -1,14 +1,16 @@
-from .base import Command
 from clickable.logger import logger
 
+from .base import Command
+
 
 class DevicesCommand(Command):
-    aliases = []
-    name = 'devices'
-    help = 'Lists all connected devices'
+    def __init__(self):
+        super().__init__()
+        self.cli_conf.name = 'devices'
+        self.cli_conf.help_msg = 'Lists all ADB devices'
 
-    def run(self, path_arg=None):
-        devices = self.device.detect_attached()
+    def run(self):
+        devices = self.device.detect_adb_attached()
 
         if len(devices) == 0:
             logger.warning('No attached devices')
